/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                       **** PENSAMIENTO MATEMATICO ****
/*
/*                     Ciclo escolar evaluado: 2010 - 2011
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE PENSAMIENTO
/*                           MATEMATICO EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2011_Alum_PM.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2011_Alum_PM.txt
/*         as como el archivo Excale00_2011_Alum_PM.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2011_Alum_PM.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2011_Alum_PM.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 27 DE AGOSTO DE 2013
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale00_2011_Alum_PM.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "PUB"     ="Escuelas pblicas sin clasificar en Urbanas o Rurales. Slo se utilizan para estimacin de parmetros a nivel Nacional";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis aos"
                       4         ="Siete aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE ema1_13F
                       0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Respuesta invlida, el alumno no respondi lo que se esperaba"
                       6         ="El alumno copio la respuesta a su compaero"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE matnvlF
                       1         ="Por debajo del bsico"
                       2         ="Bsico"
                       3         ="Medio"
                       4         ="Avanzado";
     VALUE matnvlbF
                       0         ="Por debajo del bsico"
                       1         ="Al menos el nivel bsico";

RUN;



DATA INEE.Excale00_2011_Alum_PM;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            $6
       ALUMNO             6
       ID_INSTR           $15
       SEXO               3
       FECHA_NAC          $10
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       W_ALU              8
       EMA_01             3
       EMA_02             3
       EMA_03             3
       EMA_04             3
       EMA_05             3
       EMA_06             3
       EMA_07             3
       EMA_08             3
       EMA_09             3
       EMA_10             3
       EMA_11             3
       EMA_12             3
       EMA_13             3
       EMA_14             3
       EMB_01             3
       EMB_02             3
       EMB_03             3
       EMB_04             3
       EMB_05_01          3
       EMB_05_02          3
       EMB_05_03          3
       EMB_05_04          3
       EMB_05_05          3
       EMB_06             3
       EMB_07             3
       EMB_08_02          3
       EMB_08_03          3
       EMB_08_04          3
       EMB_09             3
       EMB_10             3
       EMB_11             3
       EMB_12             3
       EMB_13             3
       EMC_01             3
       EMC_02             3
       EMC_03             3
       EMC_04             3
       EMC_05             3
       EMC_06             3
       EMC_07             3
       EMC_08             3
       EMC_09             3
       EMC_10             3
       EMC_11             3
       EMC_12             3
       EMC_13             3
       EMC_14             3
       EMD_01             3
       EMD_02             3
       EMD_03             3
       EMD_04             3
       EMD_05_01          3
       EMD_05_02          3
       EMD_05_03          3
       EMD_05_04          3
       EMD_06             3
       EMD_07             3
       EMD_08             3
       EMD_09             3
       EMD_10             3
       EMD_11             3
       EMD_12             3
       EMD_13             3
       PV1MAT             8
       PV2MAT             8
       PV3MAT             8
       PV4MAT             8
       PV5MAT             8
       MATNVL1            3
       MATNVL2            3
       MATNVL3            3
       MATNVL4            3
       MATNVL5            3
       MATNVLB1           3
       MATNVLB2           3
       MATNVLB3           3
       MATNVLB4           3
       MATNVLB5           3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
   ;

INFILE alum MISSOVER LINESIZE = 1104;
   INPUT
        NACIONAL              1 - 1
        ESCUELA               2 - 5
        ID_ENT                6 - 7
        NOM_ENT               8 - 26
        ID_MOD               27 - 27
        MOD                  28 - 31
        ESTRATO              32 - 37
        ALUMNO               38 - 42
        ID_INSTR             43 - 57
        SEXO                 58 - 58
        FECHA_NAC            59 - 68
        EDAD                 69 - 79
        EDADC                80 - 80
        EDADN                81 - 81
        EDAD_AC              82 - 83
        W_ALU                84 - 94
        EMA_01               95 - 95
        EMA_02               96 - 96
        EMA_03               97 - 97
        EMA_04               98 - 98
        EMA_05               99 - 99
        EMA_06              100 - 100
        EMA_07              101 - 101
        EMA_08              102 - 102
        EMA_09              103 - 103
        EMA_10              104 - 104
        EMA_11              105 - 105
        EMA_12              106 - 106
        EMA_13              107 - 107
        EMA_14              108 - 108
        EMB_01              109 - 109
        EMB_02              110 - 110
        EMB_03              111 - 111
        EMB_04              112 - 112
        EMB_05_01           113 - 113
        EMB_05_02           114 - 114
        EMB_05_03           115 - 115
        EMB_05_04           116 - 116
        EMB_05_05           117 - 117
        EMB_06              118 - 118
        EMB_07              119 - 119
        EMB_08_02           120 - 120
        EMB_08_03           121 - 121
        EMB_08_04           122 - 122
        EMB_09              123 - 123
        EMB_10              124 - 124
        EMB_11              125 - 125
        EMB_12              126 - 126
        EMB_13              127 - 127
        EMC_01              128 - 128
        EMC_02              129 - 129
        EMC_03              130 - 130
        EMC_04              131 - 131
        EMC_05              132 - 132
        EMC_06              133 - 133
        EMC_07              134 - 134
        EMC_08              135 - 135
        EMC_09              136 - 136
        EMC_10              137 - 137
        EMC_11              138 - 138
        EMC_12              139 - 139
        EMC_13              140 - 140
        EMC_14              141 - 141
        EMD_01              142 - 142
        EMD_02              143 - 143
        EMD_03              144 - 144
        EMD_04              145 - 145
        EMD_05_01           146 - 146
        EMD_05_02           147 - 147
        EMD_05_03           148 - 148
        EMD_05_04           149 - 149
        EMD_06              150 - 150
        EMD_07              151 - 151
        EMD_08              152 - 152
        EMD_09              153 - 153
        EMD_10              154 - 154
        EMD_11              155 - 155
        EMD_12              156 - 156
        EMD_13              157 - 157
        PV1MAT              158 - 168
        PV2MAT              169 - 179
        PV3MAT              180 - 190
        PV4MAT              191 - 201
        PV5MAT              202 - 212
        MATNVL1             213 - 213
        MATNVL2             214 - 214
        MATNVL3             215 - 215
        MATNVL4             216 - 216
        MATNVL5             217 - 217
        MATNVLB1            218 - 218
        MATNVLB2            219 - 219
        MATNVLB3            220 - 220
        MATNVLB4            221 - 221
        MATNVLB5            222 - 222
        WVARSTRR            223 - 224
        W_FSTR1             225 - 235
        W_FSTR2             236 - 246
        W_FSTR3             247 - 257
        W_FSTR4             258 - 268
        W_FSTR5             269 - 279
        W_FSTR6             280 - 290
        W_FSTR7             291 - 301
        W_FSTR8             302 - 312
        W_FSTR9             313 - 323
        W_FSTR10            324 - 334
        W_FSTR11            335 - 345
        W_FSTR12            346 - 356
        W_FSTR13            357 - 367
        W_FSTR14            368 - 378
        W_FSTR15            379 - 389
        W_FSTR16            390 - 400
        W_FSTR17            401 - 411
        W_FSTR18            412 - 422
        W_FSTR19            423 - 433
        W_FSTR20            434 - 444
        W_FSTR21            445 - 455
        W_FSTR22            456 - 466
        W_FSTR23            467 - 477
        W_FSTR24            478 - 488
        W_FSTR25            489 - 499
        W_FSTR26            500 - 510
        W_FSTR27            511 - 521
        W_FSTR28            522 - 532
        W_FSTR29            533 - 543
        W_FSTR30            544 - 554
        W_FSTR31            555 - 565
        W_FSTR32            566 - 576
        W_FSTR33            577 - 587
        W_FSTR34            588 - 598
        W_FSTR35            599 - 609
        W_FSTR36            610 - 620
        W_FSTR37            621 - 631
        W_FSTR38            632 - 642
        W_FSTR39            643 - 653
        W_FSTR40            654 - 664
        W_FSTR41            665 - 675
        W_FSTR42            676 - 686
        W_FSTR43            687 - 697
        W_FSTR44            698 - 708
        W_FSTR45            709 - 719
        W_FSTR46            720 - 730
        W_FSTR47            731 - 741
        W_FSTR48            742 - 752
        W_FSTR49            753 - 763
        W_FSTR50            764 - 774
        W_FSTR51            775 - 785
        W_FSTR52            786 - 796
        W_FSTR53            797 - 807
        W_FSTR54            808 - 818
        W_FSTR55            819 - 829
        W_FSTR56            830 - 840
        W_FSTR57            841 - 851
        W_FSTR58            852 - 862
        W_FSTR59            863 - 873
        W_FSTR60            874 - 884
        W_FSTR61            885 - 895
        W_FSTR62            896 - 906
        W_FSTR63            907 - 917
        W_FSTR64            918 - 928
        W_FSTR65            929 - 939
        W_FSTR66            940 - 950
        W_FSTR67            951 - 961
        W_FSTR68            962 - 972
        W_FSTR69            973 - 983
        W_FSTR70            984 - 994
        W_FSTR71            995 - 1005
        W_FSTR72           1006 - 1016
        W_FSTR73           1017 - 1027
        W_FSTR74           1028 - 1038
        W_FSTR75           1039 - 1049
        W_FSTR76           1050 - 1060
        W_FSTR77           1061 - 1071
        W_FSTR78           1072 - 1082
        W_FSTR79           1083 - 1093
        W_FSTR80           1094 - 1104
;



   LABEL
       NACIONAL    ="Variable auxiliar para obtener promedios nacionales"
       ESCUELA     ="Identificador de la escuela"
       ID_ENT      ="Entidad federativa (identificador numrico)"
       NOM_ENT     ="Entidad federativa"
       ID_MOD      ="Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         ="Estrato escolar o Modalidad educativa"
       ESTRATO     ="Estratos del diseo muestral con el que se estiman los parmetros y errores estndar"
       ALUMNO      ="Identificador del alumno"
       ID_INSTR    ="Identificador del cuadernillo de examen"
       SEXO        ="Sexo del alumno"
       FECHA_NAC   ="Fecha de nacimiento del alumno DD/MM/AAAA"
       EDAD        ="Edad del alumno al mes de mayo de 2011, en aos (al momento de la aplicacin)"
       EDADC       ="Edad del alumno al mes de mayo de 2011, codificada (al momento de la aplicacin)"
       EDADN       ="Edad normativa"
       EDAD_AC     ="Edad en aos cumplidos (al momento de la aplicacin)"
       W_ALU       ="Peso muestral o ponderador del alumno"
       EMA_01      ="Identifica la cantidad de elementos en colecciones de objetos de la misma clase, de trece a veinte objetos, ordenados en una lnea."
       EMA_02      ="Identifica la cantidad de elementos en colecciones de objetos de distinta clase, de siete a doce objetos, ordenados."
       EMA_03      ="Enumera de manera oral objetos desde el uno y hasta el que sabe (sabe al menos 20, y mximo 30 ) siguiendo el orden de la serie numrica."
       EMA_04      ="Identifica el lugar que ocupa una persona o un objeto dentro de una serie ordenada."
       EMA_05      ="Identifica el orden de los nmeros en forma escrita."
       EMA_06      ="Resuelve problemas que implican reunir objetos en una sola coleccin."
       EMA_07      ="Resuelve problemas que implican igualar cantidades de dos colecciones que contienen elementos de la misma clase."
       EMA_08      ="Interpreta  informacin registrada en cuadros y tablas."
       EMA_09      ="Ordena de manera creciente o decreciente objetos por tamao."
       EMA_10      ="Anticipa los cambios que ocurren en una figura geomtrica al cortarla."
       EMA_11      ="Identifica desplazamientos de objetos con respecto a otros objetos. Direccionalidad con interioridad o con orientacin."
       EMA_12      ="Identifica cmo se ven objetos desde diversos puntos espaciales: arriba, abajo, lejos, cerca, de frente y de perfil, de espaldas."
       EMA_13      ="Realiza estimaciones sobre las caractersticas medibles de sujetos, objetos y espacios."
       EMA_14      ="Distingue el instrumento  apropiado para medir peso."
       EMB_01      ="Identifica la cantidad de elementos en colecciones de objetos de la misma clase de siete a doce objetos, ordenados en un arreglo rectangular."
       EMB_02      ="Identifica la cantidad de elementos en colecciones de objetos de distinta clase, de siete a doce objetos, desordenados."
       EMB_03      ="Compara colecciones y establece relaciones en situaciones de desigualdad. Identificando donde hay menos elementos."
       EMB_04      ="Identifica el valor de las monedas."
       EMB_05_01   ="Escribe nmeros que le son dictados. (Nmero menor que tres)."
       EMB_05_02   ="Escribe nmeros que le son dictados. (Nmero mayor que dos y menor que seis)."
       EMB_05_03   ="Escribe nmeros que le son dictados. (Nmero mayor que cinco y menor que diez)."
       EMB_05_04   ="Escribe nmeros que le son dictados. (Nmero mayor que nueve y menor que veinte)."
       EMB_05_05   ="Escribe nmeros que le son dictados. (Nmero mayor que diecinueve y menor que treinta)."
       EMB_06      ="Resuelve problemas que implican comparar la cantidad de dos colecciones."
       EMB_07      ="Resuelve problemas que implican repartir objetos."
       EMB_08_02   ="Registra informacin respecto a un solo elemento en grficas sencillas."
       EMB_08_03   ="Registra informacin de ms de un elemento en grficas sencillas."
       EMB_08_04   ="Registra correctamente en grficas sencillas informacin de objetos que son ms pequeos y a la vez ms numerosos que otros elementos."
       EMB_09      ="Identifica la coleccin que sigue en una serie de colecciones."
       EMB_10      ="Identifica los cambios que ocurren en una figura geomtrica al combinarla con otras iguales o diferentes."
       EMB_11      ="Identifica posiciones de objetos con respecto a otros objetos. Orientacin e interioridad."
       EMB_12      ="Resuelve problemas que impliquen medir longitudes."
       EMB_13      ="Establece relaciones temporales (antes-despus-al final)."
       EMC_01      ="Identifica la cantidad de elementos en colecciones de objetos de distinta clase, de trece a veinte objetos, ordenados."
       EMC_02      ="Compara colecciones y establece relaciones de igualdad."
       EMC_03      ="Resuelve problemas que implican usar la equivalencia del valor de las monedas."
       EMC_04      ="Distingue todos los nmeros de las letras en un texto."
       EMC_05      ="Escribe los nmeros que sabe en orden ascendente, sin equivocarse, empezando desde uno y llegando a un rango entre 31 y 89."
       EMC_06      ="Resuelve problemas que implican quitar objetos a una coleccin."
       EMC_07      ="Identifica patrones no numricos."
       EMC_08      ="Identifica la coleccin faltante en una serie de colecciones."
       EMC_09      ="Identifica ms de una de tres figuras semejantes a una muestra."
       EMC_10      ="Identifica tres o ms, de cinco figuras geomtricas a partir de solicitarle que identifique todas las que tienen un nmero determinado de lados del mismo tamao."
       EMC_11      ="Identifica posiciones de objetos con respecto a otros objetos. Orientacin y proximidad."
       EMC_12      ="Identifica posiciones de objetos con respecto a otros objetos.  Interioridad y proximidad."
       EMC_13      ="Estima el nmero exacto de veces que cabe la longitud de un objeto pequeo respecto a la longitud de un objeto mas grande."
       EMC_14      ="Utiliza correctamente los das de la semana."
       EMD_01      ="Identifica la cantidad de elementos en colecciones de objetos de la misma clase, de siete a doce objetos, desordenados."
       EMD_02      ="Compara colecciones y establece relaciones en situaciones de desigualdad, identificando donde hay mas elementos."
       EMD_03      ="Dice los nmeros que sabe en orden ascendente, sin equivocarse, empezando desde el uno y llegando a un rango de 31 a 89."
       EMD_04      ="Identifica usos de los nmeros."
       EMD_05_01   ="Utiliza nmeros para representar cantidades menores a siete."
       EMD_05_02   ="Utiliza nmeros para representar cantidades mayores a nueve pero menores a trece."
       EMD_05_03   ="Utiliza nmeros para representar cantidades mayores a seis pero menores a diez."
       EMD_05_04   ="Utiliza nmeros para representar cantidades mayores a trece pero menores a veintiuno"
       EMD_06      ="Resuelve problemas que implican agregar."
       EMD_07      ="Resuelve problemas que implican igualar cantidades de dos colecciones que contienen elementos de distinta clase."
       EMD_08      ="Interpreta informacin registrada en grficas."
       EMD_09      ="Ordena de manera creciente objetos por tonalidad."
       EMD_10      ="A partir de un cuerpo geomtrico que se le muestra, identifica ms de uno de tres objetos similares en una coleccin de cuerpos geomtricos."
       EMD_11      ="Identifica la direccionalidad de un recorrido o trayectoria y sus puntos de referencia."
       EMD_12      ="Identifica el objeto que cumple con una condicin medible: ms largo que, ms corto que."
       EMD_13      ="Identifica el objeto que cumple con una condicin medible: lleno, vaco."
       PV1MAT      ="Primer valor plausible de Matemticas"
       PV2MAT      ="Segundo valor plausible de Matemticas"
       PV3MAT      ="Tercer valor plausible de Matemticas"
       PV4MAT      ="Cuarto valor plausible de Matemticas"
       PV5MAT      ="Quinto valor plausible de Matemticas"
       MATNVL1     ="Nivel de logro en Matemticas. Asociado a pv1mat. (Cuatro niveles)"
       MATNVL2     ="Nivel de logro en Matemticas. Asociado a pv2mat. (Cuatro niveles)"
       MATNVL3     ="Nivel de logro en Matemticas. Asociado a pv3mat. (Cuatro niveles)"
       MATNVL4     ="Nivel de logro en Matemticas. Asociado a pv4mat. (Cuatro niveles)"
       MATNVL5     ="Nivel de logro en Matemticas. Asociado a pv5mat. (Cuatro niveles)"
       MATNVLB1    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv1mat."
       MATNVLB2    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv2mat."
       MATNVLB3    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv3mat."
       MATNVLB4    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv4mat."
       MATNVLB5    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv5mat."
       WVARSTRR    ="Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       ESTRATO            $char6.
       ALUMNO             5.
       ID_INSTR           $char15.
       SEXO               sexoF.
       FECHA_NAC          $char10.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       EMA_01             ema1_13F.
       EMA_02             ema1_13F.
       EMA_03             ema1_13F.
       EMA_04             ema1_13F.
       EMA_05             ema1_13F.
       EMA_06             ema1_13F.
       EMA_07             ema1_13F.
       EMA_08             ema1_13F.
       EMA_09             ema1_13F.
       EMA_10             ema1_13F.
       EMA_11             ema1_13F.
       EMA_12             ema1_13F.
       EMA_13             ema1_13F.
       EMA_14             ema1_13F.
       EMB_01             ema1_13F.
       EMB_02             ema1_13F.
       EMB_03             ema1_13F.
       EMB_04             ema1_13F.
       EMB_05_01          ema1_13F.
       EMB_05_02          ema1_13F.
       EMB_05_03          ema1_13F.
       EMB_05_04          ema1_13F.
       EMB_05_05          ema1_13F.
       EMB_06             ema1_13F.
       EMB_07             ema1_13F.
       EMB_08_02          ema1_13F.
       EMB_08_03          ema1_13F.
       EMB_08_04          ema1_13F.
       EMB_09             ema1_13F.
       EMB_10             ema1_13F.
       EMB_11             ema1_13F.
       EMB_12             ema1_13F.
       EMB_13             ema1_13F.
       EMC_01             ema1_13F.
       EMC_02             ema1_13F.
       EMC_03             ema1_13F.
       EMC_04             ema1_13F.
       EMC_05             ema1_13F.
       EMC_06             ema1_13F.
       EMC_07             ema1_13F.
       EMC_08             ema1_13F.
       EMC_09             ema1_13F.
       EMC_10             ema1_13F.
       EMC_11             ema1_13F.
       EMC_12             ema1_13F.
       EMC_13             ema1_13F.
       EMC_14             ema1_13F.
       EMD_01             ema1_13F.
       EMD_02             ema1_13F.
       EMD_03             ema1_13F.
       EMD_04             ema1_13F.
       EMD_05_01          ema1_13F.
       EMD_05_02          ema1_13F.
       EMD_05_03          ema1_13F.
       EMD_05_04          ema1_13F.
       EMD_06             ema1_13F.
       EMD_07             ema1_13F.
       EMD_08             ema1_13F.
       EMD_09             ema1_13F.
       EMD_10             ema1_13F.
       EMD_11             ema1_13F.
       EMD_12             ema1_13F.
       EMD_13             ema1_13F.
       MATNVL1            matnvlf.
       MATNVL2            matnvlf.
       MATNVL3            matnvlf.
       MATNVL4            matnvlf.
       MATNVL5            matnvlf.
       MATNVLB1           matnvlbf.
       MATNVLB2           matnvlbf.
       MATNVLB3           matnvlbf.
       MATNVLB4           matnvlbf.
       MATNVLB5           matnvlbf.
       WVARSTRR           2.

   ;


/**************************************************************************
/*  Definicin de valores perdidos
/*   .I o I = Respuesta invlida (el alumno no respondi lo que se esperaba).
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(2)  edad edad_ac;
   DO  i=1 TO 2;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;


   ARRAY perdidos3(63)
                   ema_01 ema_02 ema_03 ema_05 ema_05 ema_06 ema_07 ema_08 ema_09
                   ema_10 ema_11 ema_12 ema_13 ema_14 emb_01 emb_02 emb_03 emb_04
                   emb_05_01 emb_05_02 emb_05_03 emb_05_04 emb_05_05 emb_06 emb_07
                   emb_08_02 emb_08_03 emb_08_04 emb_09 emb_10 emb_11 emb_12 emb_13
                   emc_01 emc_02 emc_03 emc_04 emc_05 emc_06 emc_07 emc_08 emc_09
                   emc_10 emc_11 emc_12 emc_13 emc_14 emd_01 emd_02 emd_03 emd_04
                   emd_05_01 emd_05_02 emd_05_03 emd_05_04 emd_06 emd_07 emd_08
                   emd_09 emd_10 emd_11 emd_12 emd_13;
   DO  i=1 TO 63;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .I;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;



